/*
 * kdingsystray.cpp
 *
 * Copyright (c) 2005 Michael Rex <me@rexi.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "kdingsystray.h"
#include "kding.h"
#include "translatedialog.h"
#include "translator.h"

//#include <kaboutapplication.h>
//#include <kbugreport.h>
#include <kiconloader.h>
#include <kkeydialog.h>
#include <klocale.h>

#include <qclipboard.h>
#include <qevent.h>
#include <qpixmap.h>
#include <qtooltip.h>

/**
 *
 */
KDingSysTray::KDingSysTray(QWidget* parent, const char* name)
    : KSystemTray(parent, name)
{
    setPixmap(loadIcon("kding"));
    
    QToolTip::add(this, i18n("KDing - translation tool"));

    // init global shortcuts
    accel = new KGlobalAccel(this);
    accel->insert("translateClipboard", i18n("Translate clipboard contents"),
        i18n("Translates the current content of the clipboard or selection"),
        KKey::QtWIN+SHIFT+Key_T, CTRL+SHIFT+Key_T, this, SLOT(translate()));
    accel->insert("translateGivenWord", i18n("Open translation dialog"),
        i18n("Opens a dialog where you can enter the word to be translated"),
        KKey::QtWIN+SHIFT+Key_W, CTRL+SHIFT+Key_W, this, SLOT(translateWord()));

    // load user shortcut settings
    accel->readSettings();
    accel->updateConnections();
    
    menu = contextMenu();
    menu->insertItem(SmallIcon("babelfish"), i18n("&Translate"), this, SLOT(translate()));
    menu->insertItem(SmallIcon("babelfish"), i18n("Translate &word..."), this, SLOT(translateWord()));
    menu->insertItem(SmallIcon("configure_shortcuts"), i18n("Configure &global shortcuts..."), this, SLOT(showShortcuts()));
    menu->insertSeparator();
//    menu->insertItem(i18n("&Report Bug..."), this, SLOT(showReportBug()));
//    menu->insertItem(kapp->miniIcon(), i18n("&About KDing"), this, SLOT(showAbout()));
    
    help = new KHelpMenu(this, kapp->aboutData(), false);
    menu->insertItem(SmallIcon("help"), i18n("&Help"), help->menu());
}

KDingSysTray::~KDingSysTray()
{
}

/*
 * public slots
 */

void KDingSysTray::translate() const
{
    QClipboard* cb = KApplication::clipboard();
    dynamic_cast<KDing*>(kapp)->translator()->translate(cb->text(QClipboard::Selection));
}

void KDingSysTray::translateWord()
{
    TranslateDialog* dialog = new TranslateDialog(this);
    dialog->show();
}

/*
void KDingSysTray::showAbout()
{
    KAboutApplication* about = new KAboutApplication(this);
    about->show();
}

void KDingSysTray::showReportBug()
{
    KBugReport* report = new KBugReport(this);
    report->show();
}
*/

void KDingSysTray::showShortcuts()
{
    KKeyDialog::configure(accel);
    accel->writeSettings();
}

/*
 * protected methods
 */

/**
 * Overridden to change behaviour of left mouse button.
 * @param e 
 */
void KDingSysTray::mousePressEvent(QMouseEvent* e)
{
    KSystemTray::mousePressEvent(e);
    
    if(e->button() == LeftButton)
        translate();
}
